@@ -15,7 +15,7 @@ export const stripUser = user => {
   return userData;
 };
 
-export const getToken = async (data, secret, options) => sign(data, secret, options);
+export const buildToken = async (data, secret, options) => sign(data, secret, options);
 
 export const getRandomBase64String = async (length, encoding = 'base64') => {
   return new Promise((resolve, reject) => {
