@@ -14,7 +14,8 @@ async function mapErr(promise, fn) {
 
 export function createHandler(FhirResource) {
   return asyncHandler(async (req, res) => {
-    const { FhirJob } = req.store.models;
+    const { settings, store } = req;
+    const { FhirJob } = store.models;
     const validated = await mapErr(
       FhirResource.INTAKE_SCHEMA.shape({
         resourceType: yup
@@ -31,6 +32,7 @@ export function createHandler(FhirResource) {
 
     const resource = new FhirResource(validated);
     const upstream = await resource.pushUpstream({
+      settings,
       requesterId: req.user?.id,
     });
     if (FhirResource.CAN_DO.has(FHIR_INTERACTIONS.INTERNAL.MATERIALISE)) {
